package cn.iocoder.yudao.module.jx.mapper;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolFeedback;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 反馈Mapper接口
 *
 * @author ruoyi
 * @date 2024-04-27
 */
@Mapper
public interface DriveSchoolFeedbackMapper
{
    /**
     * 查询反馈
     *
     * @param id 反馈主键
     * @return 反馈
     */
    public DriveSchoolFeedback selectDriveSchoolFeedbackById(Long id);

    /**
     * 查询反馈列表
     *
     * @param driveSchoolFeedback 反馈
     * @return 反馈集合
     */
    public IPage<DriveSchoolFeedback> selectDriveSchoolFeedbackList(@Param("entity") DriveSchoolFeedback driveSchoolFeedback, Page<DriveSchoolFeedback> page);
    public List<DriveSchoolFeedback> selectDriveSchoolFeedbackListAll(@Param("entity") DriveSchoolFeedback driveSchoolFeedback);
    public Integer likeOne(DriveSchoolFeedback driveSchoolFeedback);
    public Integer likeTwo(DriveSchoolFeedback driveSchoolFeedback);
    public Integer likeThree(DriveSchoolFeedback driveSchoolFeedback);

    /**
     * 新增反馈
     *
     * @param driveSchoolFeedback 反馈
     * @return 结果
     */
    public int insertDriveSchoolFeedback(DriveSchoolFeedback driveSchoolFeedback);

    /**
     * 修改反馈
     *
     * @param driveSchoolFeedback 反馈
     * @return 结果
     */
    public int updateDriveSchoolFeedback(DriveSchoolFeedback driveSchoolFeedback);

    /**
     * 删除反馈
     *
     * @param id 反馈主键
     * @return 结果
     */
    public int deleteDriveSchoolFeedbackById(Long id);

    /**
     * 批量删除反馈
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDriveSchoolFeedbackByIds(Long[] ids);

    void insertData(@Param("userId") Long userId, @Param("content") String content);
}
